@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2018-2019 NVIDIA Corporation
+    Copyright (c) 2018-2023 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -476,8 +476,7 @@ NV_STATUS uvm_ats_ibm_service_fault(uvm_gpu_va_space_t *gpu_va_space,
 {
     uvm_va_space_t *va_space = gpu_va_space->va_space;
     struct mm_struct *mm = va_space->va_space_mm.mm;
-    int write = (access_type >= UVM_FAULT_ACCESS_TYPE_WRITE);
-    int force = 0;
+    unsigned int gup_flags = (access_type >= UVM_FAULT_ACCESS_TYPE_WRITE) ? FOLL_WRITE : 0;
     struct page *page;
     char *mapping;
     int ret;
@@ -488,7 +487,7 @@ NV_STATUS uvm_ats_ibm_service_fault(uvm_gpu_va_space_t *gpu_va_space,
     uvm_assert_mmap_lock_locked(mm);
 
     // TODO: Bug 2103669: Service more than a single fault at a time
-    ret = NV_GET_USER_PAGES_REMOTE(NULL, mm, (unsigned long)fault_addr, 1, write, force, &page, NULL);
+    ret = NV_GET_USER_PAGES_REMOTE(mm, (unsigned long)fault_addr, 1, gup_flags, &page, NULL, NULL);
     if (ret < 0)
         return errno_to_nv_status(ret);
 
